==> haskell-conduit-parse-0.2.1.1-302.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-KY2VXVsm7Pf4EdUEsh1TCl
key:                  conduit-parse-0.2.1.1-KY2VXVsm7Pf4EdUEsh1TCl
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  08c26c4083940f26831fba6dc74dff3c
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-KY2VXVsm7Pf4EdUEsh1TCl
depends:
    base-4.18.2.1 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-303-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-K22E6x2csHtJqEAHopmFKW
key:                  conduit-parse-0.2.1.1-K22E6x2csHtJqEAHopmFKW
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  a27e8e4d5cb2ad034641be763b305e81
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-K22E6x2csHtJqEAHopmFKW
depends:
    base-4.18.2.1 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
